@@ -15,7 +15,7 @@ from cryptography.hazmat.backends import default_backend
 from cryptography.hazmat.primitives.asymmetric import dsa, ec, rsa
 from lxml import etree
 
-sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')))
+sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), "..")))
 from signxml import (  # noqa
     InvalidCertificate,
     InvalidDigest,
@@ -63,12 +63,16 @@ class TestVerifyXML(unittest.TestCase):
 
 class TestSignXML(unittest.TestCase):
     def setUp(self):
-        self.example_xml_files = (os.path.join(os.path.dirname(__file__), "example.xml"),
-                                  os.path.join(os.path.dirname(__file__), "example2.xml"))
-        self.keys = dict(hmac=b"secret",
-                         rsa=rsa.generate_private_key(public_exponent=65537, key_size=2048, backend=default_backend()),
-                         dsa=dsa.generate_private_key(key_size=1024, backend=default_backend()),
-                         ecdsa=ec.generate_private_key(curve=ec.SECP384R1(), backend=default_backend()))
+        self.example_xml_files = (
+            os.path.join(os.path.dirname(__file__), "example.xml"),
+            os.path.join(os.path.dirname(__file__), "example2.xml"),
+        )
+        self.keys = dict(
+            hmac=b"secret",
+            rsa=rsa.generate_private_key(public_exponent=65537, key_size=2048, backend=default_backend()),
+            dsa=dsa.generate_private_key(key_size=1024, backend=default_backend()),
+            ecdsa=ec.generate_private_key(curve=ec.SECP384R1(), backend=default_backend()),
+        )
 
     def test_basic_signxml_statements(self):
         with self.assertRaisesRegex(InvalidInput, "Unknown signature method"):
@@ -80,9 +84,11 @@ class TestSignXML(unittest.TestCase):
         digest_algs = {"sha1", "sha224", "sha256", "sha384", "sha512"}
         sig_algs = {"hmac", "dsa", "rsa", "ecdsa"}
         hash_algs = {"sha1", "sha256"}
-        c14n_algs = {"http://www.w3.org/2001/10/xml-exc-c14n#",
-                     "http://www.w3.org/2001/10/xml-exc-c14n#WithComments",
-                     XMLSignatureProcessor.default_c14n_algorithm}
+        c14n_algs = {
+            "http://www.w3.org/2001/10/xml-exc-c14n#",
+            "http://www.w3.org/2001/10/xml-exc-c14n#WithComments",
+            XMLSignatureProcessor.default_c14n_algorithm,
+        }
 
         all_methods = itertools.product(digest_algs, sig_algs, hash_algs, methods, c14n_algs)
         for digest_alg, sig_alg, hash_alg, method, c14n_alg in all_methods:
@@ -95,23 +101,27 @@ class TestSignXML(unittest.TestCase):
                     continue
                 print(digest_alg, sig_alg, hash_alg, c14n_alg, method, type(d))
                 reset_tree(d, method)
-                signer = XMLSigner(method=method,
-                                   signature_algorithm="-".join([sig_alg, hash_alg]),
-                                   digest_algorithm=digest_alg,
-                                   c14n_algorithm=c14n_alg)
-                signed = signer.sign(d,
-                                     key=self.keys[sig_alg],
-                                     reference_uri="URI" if method == methods.detached else None)
+                signer = XMLSigner(
+                    method=method,
+                    signature_algorithm="-".join([sig_alg, hash_alg]),
+                    digest_algorithm=digest_alg,
+                    c14n_algorithm=c14n_alg,
+                )
+                signed = signer.sign(
+                    d, key=self.keys[sig_alg], reference_uri="URI" if method == methods.detached else None
+                )
                 # print(etree.tostring(signed))
                 hmac_key = self.keys["hmac"] if sig_alg == "hmac" else None
                 verify_kwargs = dict(require_x509=False, hmac_key=hmac_key, validate_schema=True)
 
                 if method == methods.detached:
+
                     def resolver(uri):
                         if isinstance(d, stdlibElementTree.Element):
                             return etree.fromstring(stdlibElementTree.tostring(d))
                         else:
                             return d
+
                     verify_kwargs["uri_resolver"] = resolver
 
                 signed_data = etree.tostring(signed)
@@ -148,7 +158,7 @@ class TestSignXML(unittest.TestCase):
                     mangled_sig = re.sub(
                         b"<ds:SignatureValue>(.+?)</ds:SignatureValue>",
                         b"<ds:SignatureValue>" + b64encode(b64decode(sig_value)[::-1]) + b"</ds:SignatureValue>",
-                        signed_data
+                        signed_data,
                     )
                     XMLVerifier().verify(mangled_sig, **verify_kwargs)
 
@@ -206,6 +216,7 @@ class TestSignXML(unittest.TestCase):
         def get_x509_cert(**kwargs):
             from cryptography.x509 import load_der_x509_certificate
             from OpenSSL.crypto import X509
+
             with open(os.path.join(interop_dir, "TR2012", "rsa-cert.der"), "rb") as fh:
                 return [X509.from_cryptography(load_der_x509_certificate(fh.read(), backend=default_backend()))]
 
@@ -215,8 +226,13 @@ class TestSignXML(unittest.TestCase):
             with open(signature_file, "rb") as fh:
                 try:
                     sig = fh.read()
-                    XMLVerifier().verify(sig, require_x509=False, hmac_key="testkey", validate_schema=True,
-                                         cert_resolver=get_x509_cert if "x509digest" in signature_file else None)
+                    XMLVerifier().verify(
+                        sig,
+                        require_x509=False,
+                        hmac_key="testkey",
+                        validate_schema=True,
+                        cert_resolver=get_x509_cert if "x509digest" in signature_file else None,
+                    )
                     sig.decode("utf-8")
                 except Exception as e:
                     if "keyinforeference" in signature_file:
@@ -274,27 +290,46 @@ class TestSignXML(unittest.TestCase):
             with open(signature_file, "rb") as fh:
                 try:
                     sig = fh.read()
-                    XMLVerifier().verify(sig,
-                                         require_x509=False,
-                                         hmac_key="test" if "phaos" in signature_file else "secret",
-                                         validate_schema=True,
-                                         uri_resolver=resolver,
-                                         x509_cert=get_x509_cert(signature_file),
-                                         cert_resolver=cert_resolver if "issuer-serial" in signature_file else None,
-                                         ca_pem_file=get_ca_pem_file(signature_file))
+                    verifier = XMLVerifier()
+                    verifier.excise_empty_xmlns_declarations = True
+                    verifier.verify(
+                        sig,
+                        require_x509=False,
+                        hmac_key="test" if "phaos" in signature_file else "secret",
+                        validate_schema=True,
+                        uri_resolver=resolver,
+                        x509_cert=get_x509_cert(signature_file),
+                        cert_resolver=cert_resolver if "issuer-serial" in signature_file else None,
+                        ca_pem_file=get_ca_pem_file(signature_file),
+                    )
                     decoded_sig = sig.decode("utf-8")
                     if "HMACOutputLength" in decoded_sig or "bad" in signature_file or "expired" in signature_file:
                         raise BaseException("Expected an exception to occur")
                 except Exception as e:
-                    unsupported_cases = ("xpath-transform", "xslt-transform", "xpointer",
-                                         "x509-data-ski", "x509-data-subject-name",
-                                         "x509data", "signature-x509-ski", "signature-x509-is")
-                    bad_interop_cases = ("signature-big", "enveloping-dsa-x509chain",
-                                         "enveloping-sha512-hmac-sha512", "enveloping-sha512-rsa-sha512",
-                                         "enveloping-rsa-x509chain", "enveloping-sha1-rsa-sha1",
-                                         "enveloping-sha224-rsa-sha224", "enveloping-sha256-rsa-sha256",
-                                         "enveloping-sha384-rsa-sha384")
-                    if signature_file.endswith("expired-cert.xml") or signature_file.endswith("wsfederation_metadata.xml"): # noqa
+                    unsupported_cases = (
+                        "xpath-transform",
+                        "xslt-transform",
+                        "xpointer",
+                        "x509-data-ski",
+                        "x509-data-subject-name",
+                        "x509data",
+                        "signature-x509-ski",
+                        "signature-x509-is",
+                    )
+                    bad_interop_cases = (
+                        "signature-big",
+                        "enveloping-dsa-x509chain",
+                        "enveloping-sha512-hmac-sha512",
+                        "enveloping-sha512-rsa-sha512",
+                        "enveloping-rsa-x509chain",
+                        "enveloping-sha1-rsa-sha1",
+                        "enveloping-sha224-rsa-sha224",
+                        "enveloping-sha256-rsa-sha256",
+                        "enveloping-sha384-rsa-sha384",
+                    )
+                    if signature_file.endswith("expired-cert.xml") or signature_file.endswith(
+                        "wsfederation_metadata.xml"
+                    ):  # noqa
                         with self.assertRaisesRegex(InvalidCertificate, "certificate has expired"):
                             raise
                     elif signature_file.endswith("invalid_enveloped_transform.xml"):
@@ -330,7 +365,9 @@ class TestSignXML(unittest.TestCase):
                         print("Unsupported test case:", type(e), e)
                     elif any(x in signature_file for x in bad_interop_cases) or "Unable to resolve reference" in str(e):
                         print("Bad interop test case:", type(e), e)
-                    elif "certificate has expired" in str(e) and ("signature-dsa" in signature_file or "signature-rsa" in signature_file): # noqa
+                    elif "certificate has expired" in str(e) and (
+                        "signature-dsa" in signature_file or "signature-rsa" in signature_file
+                    ):  # noqa
                         print("IGNORED:", type(e), e)
                     elif "TR2012" not in signature_file:
                         raise
@@ -338,23 +375,22 @@ class TestSignXML(unittest.TestCase):
     def test_signxml_changing_signature_namespace_prefix(self):
         data = etree.parse(self.example_xml_files[0]).getroot()
         signer = XMLSigner()
-        signer.namespaces = dict(digi_sign=namespaces['ds'])
+        signer.namespaces = dict(digi_sign=namespaces["ds"])
         signed = signer.sign(data, key=self.keys["rsa"])
         signed_data = etree.tostring(signed)
-        expected_match = ("<digi_sign:Signature xmlns:"
-                          "digi_sign=\"%s\">") % namespaces['ds']
-        self.assertTrue(re.search(expected_match.encode('ascii'), signed_data))
+        expected_match = ("<digi_sign:Signature xmlns:" 'digi_sign="%s">') % namespaces["ds"]
+        self.assertTrue(re.search(expected_match.encode("ascii"), signed_data))
 
     def test_signxml_changing_signature_namespace_prefix_to_default(self):
         data = etree.parse(self.example_xml_files[0]).getroot()
         signer = XMLSigner()
         ns = dict()
-        ns[None] = namespaces['ds']
+        ns[None] = namespaces["ds"]
         signer.namespaces = ns
         signed = signer.sign(data, key=self.keys["rsa"])
         signed_data = etree.tostring(signed)
-        expected_match = ("<Signature xmlns=\"%s\">") % namespaces['ds']
-        self.assertTrue(re.search(expected_match.encode('ascii'), signed_data))
+        expected_match = ('<Signature xmlns="%s">') % namespaces["ds"]
+        self.assertTrue(re.search(expected_match.encode("ascii"), signed_data))
 
     def test_elementtree_compat(self):
         data = stdlibElementTree.parse(self.example_xml_files[0]).getroot()
@@ -368,14 +404,15 @@ class TestSignXML(unittest.TestCase):
             key = fh.read()
 
         # Both ID and Id formats. XPath 1 doesn't have case insensitive attribute search
-        for d in ['''<samlp:Response xmlns:samlp="urn:oasis:names:tc:SAML:2.0:protocol"
+        for d in [
+            """<samlp:Response xmlns:samlp="urn:oasis:names:tc:SAML:2.0:protocol"
                                      xmlns:saml="urn:oasis:names:tc:SAML:2.0:assertion" ID="responseId">
                       <saml:Assertion xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                                       xmlns:xs="http://www.w3.org/2001/XMLSchema" ID="assertionId">
                        <ds:Signature xmlns:ds="http://www.w3.org/2000/09/xmldsig#" Id="placeholder" />
                       </saml:Assertion>
-                     </samlp:Response>''',
-                  '''<samlp:Response xmlns:samlp="urn:oasis:names:tc:SAML:2.0:protocol"
+                     </samlp:Response>""",
+            """<samlp:Response xmlns:samlp="urn:oasis:names:tc:SAML:2.0:protocol"
                                      xmlns:saml="urn:oasis:names:tc:SAML:2.0:assertion" Id="responseId">
                       <saml:Assertion xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                                       xmlns:xs="http://www.w3.org/2001/XMLSchema" Id="assertionId">
@@ -384,18 +421,23 @@ class TestSignXML(unittest.TestCase):
                       <saml:Assertion xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
                                       xmlns:xs="http://www.w3.org/2001/XMLSchema" Id="assertion2">
                       </saml:Assertion>
-                     </samlp:Response>''']:
+                     </samlp:Response>""",
+        ]:
             data = etree.fromstring(d)
             reference_uri = ["assertionId", "assertion2"] if "assertion2" in d else "assertionId"
             signed_root = XMLSigner().sign(data, reference_uri=reference_uri, key=key, cert=crt)
-            signed_data_root = XMLVerifier().verify(etree.tostring(signed_root),
-                                                    x509_cert=crt,
-                                                    expect_references=True)[1]
-            ref = signed_root.xpath('/samlp:Response/saml:Assertion/ds:Signature/ds:SignedInfo/ds:Reference',
-                                    namespaces={"ds": "http://www.w3.org/2000/09/xmldsig#",
-                                                "saml": "urn:oasis:names:tc:SAML:2.0:assertion",
-                                                "samlp": "urn:oasis:names:tc:SAML:2.0:protocol"})
-            self.assertEqual("assertionId", ref[0].attrib['URI'][1:])
+            signed_data_root = XMLVerifier().verify(etree.tostring(signed_root), x509_cert=crt, expect_references=True)[
+                1
+            ]
+            ref = signed_root.xpath(
+                "/samlp:Response/saml:Assertion/ds:Signature/ds:SignedInfo/ds:Reference",
+                namespaces={
+                    "ds": "http://www.w3.org/2000/09/xmldsig#",
+                    "saml": "urn:oasis:names:tc:SAML:2.0:assertion",
+                    "samlp": "urn:oasis:names:tc:SAML:2.0:protocol",
+                },
+            )
+            self.assertEqual("assertionId", ref[0].attrib["URI"][1:])
 
             self.assertEqual("{urn:oasis:names:tc:SAML:2.0:assertion}Assertion", signed_data_root.tag)
 
@@ -418,8 +460,11 @@ class TestSignXML(unittest.TestCase):
             with open(os.path.join(os.path.dirname(__file__), "wsse_keyinfo.xml")) as fh:
                 custom_key_info = etree.fromstring(fh.read())
             s3 = signer.sign(data, reference_uri=reference_uri, key=key, cert=crt, key_info=custom_key_info)
-            self.assertTrue(s3.xpath("/ds:Signature/ds:KeyInfo/wsse:SecurityTokenReference",
-                                     namespaces=dict(namespaces, wsse=wsse_ns)))
+            self.assertTrue(
+                s3.xpath(
+                    "/ds:Signature/ds:KeyInfo/wsse:SecurityTokenReference", namespaces=dict(namespaces, wsse=wsse_ns)
+                )
+            )
 
             # Test setting both X509Data and KeyInfo
             s4 = XMLSigner().sign(data, reference_uri=reference_uri, key=key, cert=crt, always_add_key_value=True)
@@ -440,17 +485,21 @@ class TestSignXML(unittest.TestCase):
         data = etree.parse(os.path.join(wsse_dir, "test", "unit", "client", "files", "valid wss resp.xml"))
         XMLVerifier().verify(data, x509_cert=crt, validate_schema=False, expect_references=2)
 
-        data = etree.parse(os.path.join(wsse_dir, "test", "unit", "client", "files",
-                                        "invalid wss resp - changed content.xml"))
+        data = etree.parse(
+            os.path.join(wsse_dir, "test", "unit", "client", "files", "invalid wss resp - changed content.xml")
+        )
         with self.assertRaisesRegex(InvalidDigest, "Digest mismatch for reference 0"):
             XMLVerifier().verify(data, x509_cert=crt, validate_schema=False, expect_references=2)
 
     def test_psha1(self):
         from signxml.util import p_sha1
-        a, b, c, d = ("grrlUUfhuNwlvQzQ4bV6TT3wA8ieZPltIf4+H7nIvCE=",
-                      "YLABh3ZmZyiO5gvVLZe9J4JPd9w59KGeTFwE85XlzxE=",
-                      "Wv3QzY84KfgwSkn1z3QV+LXEoo3nPraZPysJYtA3u4c=",
-                      "g/uYZmYX7rOm/X7UV4usrvjIPCiWMWwNZJL0ejvz6Y4=")
+
+        a, b, c, d = (
+            "grrlUUfhuNwlvQzQ4bV6TT3wA8ieZPltIf4+H7nIvCE=",
+            "YLABh3ZmZyiO5gvVLZe9J4JPd9w59KGeTFwE85XlzxE=",
+            "Wv3QzY84KfgwSkn1z3QV+LXEoo3nPraZPysJYtA3u4c=",
+            "g/uYZmYX7rOm/X7UV4usrvjIPCiWMWwNZJL0ejvz6Y4=",
+        )
         self.assertEqual(p_sha1(a, b), c)
         self.assertEqual(p_sha1(b, a), d)
 
@@ -461,49 +510,44 @@ class TestSignXML(unittest.TestCase):
                     XMLVerifier().verify(fh.read())
 
     def test_signature_properties_with_detached_method(self):
-        doc = etree.Element('Test', attrib={'Id': 'mytest'})
-        sigprop = etree.Element('{http://somenamespace}MyCustomProperty')
-        sigprop.text = 'Some Text'
+        doc = etree.Element("Test", attrib={"Id": "mytest"})
+        sigprop = etree.Element("{http://somenamespace}MyCustomProperty")
+        sigprop.text = "Some Text"
         with open(os.path.join(os.path.dirname(__file__), "example.key"), "rb") as file:
             key = file.read()
         with open(os.path.join(os.path.dirname(__file__), "example.pem"), "rb") as file:
             cert = file.read()
-        signature = XMLSigner(method=methods.detached).sign(doc,
-                                                            cert=cert,
-                                                            key=key,
-                                                            reference_uri="#mytest",
-                                                            signature_properties=sigprop)
-        fulldoc = b'<root>' + etree.tostring(signature) + etree.tostring(doc) + b'</root>'
+        signature = XMLSigner(method=methods.detached).sign(
+            doc, cert=cert, key=key, reference_uri="#mytest", signature_properties=sigprop
+        )
+        fulldoc = b"<root>" + etree.tostring(signature) + etree.tostring(doc) + b"</root>"
         XMLVerifier().verify(etree.fromstring(fulldoc), x509_cert=cert, expect_references=2)
 
     def test_signature_properties_with_detached_method_re_enveloping(self):
-        doc = etree.Element('{http://somenamespace}Test', attrib={'Id': 'mytest'})
-        sigprop = etree.Element('{http://somenamespace}MyCustomProperty')
-        sigprop.text = 'Some Text'
+        doc = etree.Element("{http://somenamespace}Test", attrib={"Id": "mytest"})
+        sigprop = etree.Element("{http://somenamespace}MyCustomProperty")
+        sigprop.text = "Some Text"
         with open(os.path.join(os.path.dirname(__file__), "example.key"), "rb") as file:
             key = file.read()
         with open(os.path.join(os.path.dirname(__file__), "example.pem"), "rb") as file:
             cert = file.read()
-        signer = XMLSigner(method=methods.detached,
-                           c14n_algorithm="http://www.w3.org/TR/2001/REC-xml-c14n-20010315")
-        signer.namespaces['ns0'] = 'http://enveloping.namespace'
-        signature = signer.sign(doc,
-                                cert=cert,
-                                key=key,
-                                reference_uri="#mytest",
-                                signature_properties=sigprop)
-        fulldoc = b'<ns0:root xmlns:ns0="http://enveloping.namespace">' \
-            + etree.tostring(signature) \
-            + etree.tostring(doc) \
-            + b'</ns0:root>'
+        signer = XMLSigner(method=methods.detached, c14n_algorithm="http://www.w3.org/TR/2001/REC-xml-c14n-20010315")
+        signer.namespaces["ns0"] = "http://enveloping.namespace"
+        signature = signer.sign(doc, cert=cert, key=key, reference_uri="#mytest", signature_properties=sigprop)
+        fulldoc = (
+            b'<ns0:root xmlns:ns0="http://enveloping.namespace">'
+            + etree.tostring(signature)
+            + etree.tostring(doc)
+            + b"</ns0:root>"
+        )
         XMLVerifier().verify(etree.fromstring(fulldoc), x509_cert=cert, expect_references=2)
 
     def test_payload_c14n(self):
         doc = etree.fromstring('<abc xmlns="http://example.com"><foo xmlns="">bar</foo></abc>')
-        print(XMLVerifier._c14n(None, doc, algorithm=""))
-        self.assertEqual(XMLVerifier._c14n(None, doc, algorithm=""),
-                         b'<abc xmlns="http://example.com"><foo xmlns="">bar</foo></abc>')
+        self.assertEqual(
+            XMLVerifier()._c14n(doc, algorithm=""), b'<abc xmlns="http://example.com"><foo xmlns="">bar</foo></abc>'
+        )
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     unittest.main()
